import pandas as pd
import json
from wehoop.dl_utils import download



def wbb_calendar(season: int) -> pd.DataFrame:
    url = "http://site.api.espn.com/apis/site/v2/sports/basketball/womens-college-basketball/scoreboard?dates={}".format(season)
    resp = download(url=url)
    txt = json.loads(resp)['leagues'][0]['calendar']
    reg = pd.DataFrame(txt[0]['entries'])
    post = pd.DataFrame(txt[1]['entries'])
    full_schedule = pd.concat([reg,post], ignore_index=True)
    full_schedule['season']=season
    return full_schedule

def wnba_calendar(season: int) -> pd.DataFrame:
    url = "http://site.api.espn.com/apis/site/v2/sports/basketball/wnba/scoreboard?dates={}".format(season)
    resp = download(url=url)
    txt = json.loads(resp)['leagues'][0]['calendar']
    reg = pd.DataFrame(txt[0]['entries'])
    post = pd.DataFrame(txt[1]['entries'])
    full_schedule = pd.concat([reg,post], ignore_index=True)
    full_schedule['season']=season
    return full_schedule



import pyarrow.parquet as pq
import pandas as pd
from typing import List, Callable, Iterator, Union, Optional
from wehoop.config import WNBA_BASE_URL, WNBA_TEAM_BOX_URL, WNBA_PLAYER_BOX_URL, WNBA_TEAM_SCHEDULE_URL
from wehoop.errors import SeasonNotFoundError

def load_wnba_pbp(years: List[int]) -> pd.DataFrame:
    """
    Load WNBA play by play data going back to 2002
    Args:
        years (list): Used to define different seasons. 2002 is the earliest available season.
    Returns:
        pbp_df (pandas dataframe): Pandas dataframe containing
        play-by-plays available for the requested seasons.
    Raises:
        ValueError: If `year` is less than 2002.
    """
    data = pd.DataFrame()
    for i in years:
        if int(i) < 2002:
            raise SeasonNotFoundError("season cannot be less than 2002")
        i_data = pd.read_parquet(WNBA_BASE_URL.format(year=i), engine='auto', columns=None, 
        use_nullable_dtypes=False)
        data = data.append(i_data)
    #Give each row a unique index
    data.reset_index(drop=True, inplace=True)
    return data

def load_wnba_team_boxscore(years: List[int]) -> pd.DataFrame:
    """
    Load WNBA team boxscore data
    Args:
        years (list): Used to define different seasons. 2002 is the earliest available season.
    Returns:
        team_boxscore_df (pandas dataframe): Pandas dataframe containing the
        team boxscores available for the requested seasons.
    Raises:
        ValueError: If `year` is less than 2002.
    """
    data = pd.DataFrame()
    for i in years:
        if int(i) < 2002:
            raise SeasonNotFoundError("season cannot be less than 2002")
        i_data = pd.read_parquet(WNBA_TEAM_BOX_URL.format(year = i), engine='auto', columns=None, 
        use_nullable_dtypes=False)
        data = data.append(i_data)
    #Give each row a unique index
    data.reset_index(drop=True, inplace=True)

    return data

def load_wnba_player_boxscore(years: List[int]) -> pd.DataFrame:
    """
    Load WNBA player boxscore data
    Args:
        years (list): Used to define different seasons. 2002 is the earliest available season.
    Returns:
        player_boxscore_df (pandas dataframe): Pandas dataframe containing the
        player boxscores available for the requested seasons.
    Raises:
        ValueError: If `year` is less than 2002.
    """
    data = pd.DataFrame()
    for i in years:
        if int(i) < 2002:
            raise SeasonNotFoundError("season cannot be less than 2002")
        i_data = pd.read_parquet(WNBA_PLAYER_BOX_URL.format(year = i), engine='auto', columns=None, 
        use_nullable_dtypes=False)
        data = data.append(i_data)
    #Give each row a unique index
    data.reset_index(drop=True, inplace=True)

    return data

def load_wnba_schedule(years: List[int]) -> pd.DataFrame:
    """
    Load WNBA schedule data
    Args:
        years (list): Used to define different seasons. 2002 is the earliest available season.
    Returns:
        schedule_df (pandas dataframe): Pandas dataframe containing the
        schedule for  the requested seasons.
    Raises:
        ValueError: If `year` is less than 2002.
    """
    data = pd.DataFrame()
    for i in years:
        if int(i) < 2002:
            raise SeasonNotFoundError("season cannot be less than 2002")
        i_data = pd.read_parquet(WNBA_TEAM_SCHEDULE_URL.format(year = i), engine='auto', columns=None, 
        use_nullable_dtypes=False)
        data = data.append(i_data)
    #Give each row a unique index
    data.reset_index(drop=True, inplace=True)

    return data








WBB_BASE_URL = 'https://raw.githubusercontent.com/saiemgilani/wehoop-data/master/wbb/pbp/parquet/play_by_play_{year}.parquet'
WBB_TEAM_BOX_URL = 'https://raw.githubusercontent.com/saiemgilani/wehoop-data/master/wbb/team_box/parquet/player_box_{year}.parquet'
WBB_PLAYER_BOX_URL = 'https://raw.githubusercontent.com/saiemgilani/wehoop-data/master/wbb/player_box/parquet/player_box_{year}.parquet'
WBB_TEAM_LOGO_URL  = 'https://github.com/saiemgilani/wehoop-data/blob/master/wbb/teams_colors_logos.csv'
WBB_TEAM_SCHEDULE_URL = 'https://raw.githubusercontent.com/saiemgilani/wehoop-data/master/wbb/schedules/parquet/schedules_{year}.parquet'
WNBA_BASE_URL = 'https://raw.githubusercontent.com/saiemgilani/wehoop-data/master/wnba/pbp/parquet/play_by_play_{year}.parquet'
WNBA_TEAM_BOX_URL = 'https://raw.githubusercontent.com/saiemgilani/wehoop-data/master/wnba/team_box/parquet/team_box_{year}.parquet'
WNBA_PLAYER_BOX_URL  = 'https://raw.githubusercontent.com/saiemgilani/wehoop-data/master/wnba/player_box/parquet/player_box_{year}.parquet'
WNBA_TEAM_SCHEDULE_URL = 'https://raw.githubusercontent.com/saiemgilani/wehoop-data/master/wnba/schedules/parquet/schedules_{year}.parquet'
